FermiSurface3D — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# FermiSurface3D

The `pyprocar.core.FermiSurface3D` is used to store the informtation of a 3D Fermi Surface. This includes the interpolated kpoints, isosurface, and scalar value This class is an extension of the general `pyprocar.core.Isosurface` See 3D Fermi surface for further details.

`pyprocar.core.FermiSurface3D`(*args, **kwargs) | The object is used to store and manapulate a 3d fermi surface.